# Generated by Django 4.2.6 on 2024-09-09 00:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('drf_audit_trail', '0003_alter_requestauditevent_user'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProcessAuditEvent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extra_informations', models.TextField(blank=True, null=True, verbose_name='Extra information')),
                ('datetime', models.DateTimeField(auto_now_add=True, verbose_name='Datetime')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('created_by', models.CharField(blank=True, max_length=120, null=True, verbose_name='User identifier')),
                ('request', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='processes', to='drf_audit_trail.requestauditevent', verbose_name='Request')),
            ],
            options={
                'verbose_name': 'Process audit event',
                'verbose_name_plural': 'Process audit events',
                'db_table': 'process_audit_event',
            },
        ),
        migrations.CreateModel(
            name='StepAuditEvent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extra_informations', models.TextField(blank=True, null=True, verbose_name='Extra information')),
                ('datetime', models.DateTimeField(auto_now_add=True, verbose_name='Datetime')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('order', models.IntegerField()),
                ('total_registrations', models.IntegerField(default=1)),
                ('created_by', models.CharField(blank=True, max_length=120, null=True, verbose_name='User identifier')),
                ('process', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='steps', to='drf_audit_trail.processauditevent')),
            ],
            options={
                'verbose_name': 'Step audit event',
                'verbose_name_plural': 'Step audit events',
                'db_table': 'step_audit_event',
            },
        ),
        migrations.CreateModel(
            name='RegistrationAuditEvent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extra_informations', models.TextField(blank=True, null=True, verbose_name='Extra information')),
                ('datetime', models.DateTimeField(auto_now_add=True, verbose_name='Datetime')),
                ('success', models.BooleanField()),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('created_by', models.CharField(blank=True, max_length=120, null=True, verbose_name='User identifier')),
                ('step', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='registrations', to='drf_audit_trail.stepauditevent')),
            ],
            options={
                'verbose_name': 'Registration audit event',
                'verbose_name_plural': 'Registration audit events',
                'db_table': 'registration_audit_event',
            },
        ),
    ]
