# Generated by Django 4.2.13 on 2024-05-22 01:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("drf_audit_trail", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="loginauditevent",
            name="request",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE,
                to="drf_audit_trail.requestauditevent",
            ),
        ),
    ]
